@@ -7,14 +7,13 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++98, c++03, c++11
 // <experimental/chrono>
 
 #include <experimental/chrono>
 
-#if _LIBCPP_STD_VER > 11
-# ifndef _LIBCPP_CHRONO
-#   error "<experimental/chrono> must include <chrono>"
-# endif
+#ifndef _LIBCPP_CHRONO
+#  error "<experimental/chrono> must include <chrono>"
 #endif
 
 int main()
