@@ -11,6 +11,8 @@
 
 // ~stack() // implied noexcept;
 
+// UNSUPPORTED: c++98, c++03
+
 #include <stack>
 #include <cassert>
 
@@ -18,10 +20,8 @@
 
 int main()
 {
-#if __has_feature(cxx_noexcept)
     {
         typedef std::stack<MoveOnly> C;
         static_assert(std::is_nothrow_destructible<C>::value, "");
     }
-#endif
 }
