@@ -7,14 +7,13 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++98, c++03, c++11
 // <optional>
 
 // T shall be an object type and shall satisfy the requirements of Destructible
 
 #include <experimental/optional>
 
-#if _LIBCPP_STD_VER > 11
-
 using std::experimental::optional;
 
 struct X
@@ -23,13 +22,7 @@ private:
     ~X() {}
 };
 
-#endif  // _LIBCPP_STD_VER > 11
-
 int main()
 {
-#if _LIBCPP_STD_VER > 11
     optional<X> opt;
-#else
-#error
-#endif  // _LIBCPP_STD_VER > 11
 }
