@@ -15,6 +15,8 @@
 #include <experimental/string_view>
 #include <cassert>
 
+#include "test_macros.h"
+
 template<typename CharT>
 void test ( const CharT *s, size_t len ) {
     typedef std::experimental::basic_string_view<CharT> SV;
@@ -30,7 +32,7 @@ void test ( const CharT *s, size_t len ) {
     }
 }
 
-#if _LIBCPP_STD_VER > 11
+#if TEST_STD_VER > 11
 constexpr size_t test_ce ( size_t n ) {
     typedef std::experimental::basic_string_view<char> SV;
     SV sv1{ "ABCDEFGHIJKL", n };
@@ -48,7 +50,7 @@ int main () {
     test ( L"a", 1 );
     test ( L"", 0 );
 
-#if __cplusplus >= 201103L
+#if TEST_STD_VER >= 11
     test ( u"ABCDE", 5 );
     test ( u"a", 1 );
     test ( u"", 0 );
@@ -58,7 +60,7 @@ int main () {
     test ( U"", 0 );
 #endif
 
-#if _LIBCPP_STD_VER > 11
+#if TEST_STD_VER > 11
     static_assert ( test_ce (5) == 0, "" );
 #endif
 
