@@ -16,6 +16,8 @@
 #include <exception>
 #include <cassert>
 
+#include "test_macros.h"
+
 class A
 {
     int data_;
@@ -32,6 +34,7 @@ int main()
         std::nested_exception e = e0;
         assert(e.nested_ptr() == nullptr);
     }
+#ifndef TEST_HAS_NO_EXCEPTIONS
     {
         try
         {
@@ -54,4 +57,5 @@ int main()
             }
         }
     }
+#endif
 }
