@@ -15,6 +15,7 @@
 
 #include <valarray>
 #include <cassert>
+#include <cstddef>
 
 int main()
 {
@@ -27,7 +28,7 @@ int main()
         std::valarray<T> v2(a2, N);
         v1 &= 3;
         assert(v1.size() == v2.size());
-        for (int i = 0; i < v1.size(); ++i)
+        for (std::size_t i = 0; i < v1.size(); ++i)
             assert(v1[i] == v2[i]);
     }
 }
