@@ -9,21 +9,22 @@
 
 // <regex>
 
-//   template <class ST, class SA, class Allocator, class charT, class traits> 
-//   bool regex_match(const basic_string<charT, ST, SA>&&, 
+//   template <class ST, class SA, class Allocator, class charT, class traits>
+//   bool regex_match(const basic_string<charT, ST, SA>&&,
 //                    match_results<
-//                      typename basic_string<charT, ST, SA>::const_iterator, 
-//                      Allocator>&, 
-//                    const basic_regex<charT, traits>&, 
-//                    regex_constants::match_flag_type = 
+//                      typename basic_string<charT, ST, SA>::const_iterator,
+//                      Allocator>&,
+//                    const basic_regex<charT, traits>&,
+//                    regex_constants::match_flag_type =
 //                      regex_constants::match_default) = delete;
 
-#if __cplusplus <= 201402L
-#error
-#else
-
 #include <regex>
 #include <cassert>
+#include "test_macros.h"
+
+#if TEST_STD_VER < 14
+#error
+#endif
 
 int main()
 {
@@ -33,4 +34,3 @@ int main()
         std::regex_match(std::string("abcde"), m, re);
     }
 }
-#endif
