@@ -16,11 +16,12 @@
 #include <string>
 #include <cassert>
 
+#include "test_macros.h"
+
 int main()
 {
 #ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
-#if __cplusplus >= 201103L
-    char16_t c = u'\0';
+#if TEST_STD_VER >= 11
     assert(std::char_traits<char16_t>::eq(u'a', u'a'));
     assert(!std::char_traits<char16_t>::eq(u'a', u'A'));
 #endif
