@@ -16,10 +16,12 @@
 #include <string>
 #include <cassert>
 
+#include "test_macros.h"
+
 int main()
 {
 #ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
-#if __cplusplus >= 201103L
+#if TEST_STD_VER >= 11
     assert( std::char_traits<char16_t>::eq_int_type(u'a', u'a'));
     assert(!std::char_traits<char16_t>::eq_int_type(u'a', u'A'));
     assert(!std::char_traits<char16_t>::eq_int_type(std::char_traits<char16_t>::eof(), u'A'));
