@@ -9,7 +9,9 @@
 
 // This is for bugs 18853 and 19118
 
-#if __cplusplus >= 201103L
+#include "test_macros.h"
+
+#if TEST_STD_VER >= 11
 
 #include <tuple>
 #include <functional>
